@@ -61,7 +61,6 @@ import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.CopyOnWriteArrayList;
-import org.apache.commons.logging.Log;
 import org.osgi.service.event.Event;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.drive.DriveConstants;
@@ -72,6 +71,9 @@ import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.FileStorageEventHelper;
 import com.openexchange.java.Strings;
 import com.openexchange.session.Session;
+import com.openexchange.threadpool.AbstractTask;
+import com.openexchange.threadpool.ThreadPoolService;
+import com.openexchange.threadpool.behavior.CallerRunsBehavior;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
 
@@ -82,7 +84,7 @@ import com.openexchange.timer.TimerService;
  */
 public class DriveEventServiceImpl implements org.osgi.service.event.EventHandler, DriveEventService {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(DriveEventServiceImpl.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DriveEventServiceImpl.class);
 
     private final List<DriveEventPublisher> publishers;
     private final ConcurrentMap<Integer, FolderBuffer> folderBuffers;
@@ -140,7 +142,7 @@ public class DriveEventServiceImpl implements org.osgi.service.event.EventHandle
      * @param event The event to distribute
      */
     public void notifyPublishers(DriveEvent event) {
-        LOG.debug("Publishing: " + event);
+        LOG.debug("Publishing: {}", event);
         for (DriveEventPublisher publisher : publishers) {
             if (event.isRemote() && publisher.isLocalOnly()) {
                 // skip
@@ -154,7 +156,7 @@ public class DriveEventServiceImpl implements org.osgi.service.event.EventHandle
         if (null != buffer) {
             Set<String> folderIDs = buffer.getFolderIDs();
             if (null != folderIDs && 0 < folderIDs.size()) {
-                notifyPublishers(new DriveEventImpl(buffer.getContexctID(), folderIDs, false));
+                notifyPublishers(new DriveEventImpl(buffer.getContexctID(), folderIDs, false, buffer.getPushToken()));
             }
         }
     }
@@ -165,64 +167,83 @@ public class DriveEventServiceImpl implements org.osgi.service.event.EventHandle
     }
 
     @Override
-    public void handleEvent(Event event) {
+    public void handleEvent(final Event event) {
+        LOG.trace("{}", new Object() { @Override public String toString() { return FileStorageEventHelper.createDebugMessage("event", event);}});
         /*
          * check event
          */
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(FileStorageEventHelper.createDebugMessage("event", event));
-        }
         if (false == check(event)) {
-            if (LOG.isDebugEnabled()) {
-                LOG.debug("Unable to handle incomplete event: " + event);
-            }
+            LOG.debug("Unable to handle incomplete event: {}", event);
             return;
         }
-        /*
-         * extract properties
-         */
         String fileName = (String)event.getProperty(FILE_NAME);
         if (false == Strings.isEmpty(fileName) && fileName.endsWith(DriveConstants.FILEPART_EXTENSION)) {
-            LOG.trace("Skipping event processing for temporary file: " + fileName);
+            LOG.trace("Skipping event processing for temporary file: {}", fileName);
             return;
         }
-        Session session = (Session)event.getProperty(SESSION);
-        Integer contextID = Integer.valueOf(session.getContextId());
-        String folderID = (String)(event.containsProperty(PARENT_FOLDER_ID) ?
-            event.getProperty(PARENT_FOLDER_ID) : event.getProperty(FOLDER_ID));
-        String[] folderPath = (String[])event.getProperty(FOLDER_PATH);
         /*
-         * get buffer for this context
+         * create task to insert affected folders into buffer
          */
-        FolderBuffer buffer = folderBuffers.get(contextID);
-        if (null == buffer) {
-            buffer = new FolderBuffer(contextID, consolidationTime, maxDelayTime, defaultDelayTime);
-            FolderBuffer existingBuffer = folderBuffers.putIfAbsent(Integer.valueOf(contextID), buffer);
-            if (null != existingBuffer) {
-                buffer = existingBuffer;
+        AbstractTask<Void> insertTask = new AbstractTask<Void>() {
+
+            @Override
+            public Void call() throws Exception {
+                /*
+                 * extract properties
+                 */
+                Session session = (Session)event.getProperty(SESSION);
+                Integer contextID = Integer.valueOf(session.getContextId());
+                String folderID = (String)(event.containsProperty(PARENT_FOLDER_ID) ?
+                    event.getProperty(PARENT_FOLDER_ID) : event.getProperty(FOLDER_ID));
+                String[] folderPath = (String[])event.getProperty(FOLDER_PATH);
+                /*
+                 * get buffer for this context
+                 */
+                FolderBuffer buffer = folderBuffers.get(contextID);
+                if (null == buffer) {
+                    buffer = new FolderBuffer(contextID, consolidationTime, maxDelayTime, defaultDelayTime);
+                    FolderBuffer existingBuffer = folderBuffers.putIfAbsent(Integer.valueOf(contextID), buffer);
+                    if (null != existingBuffer) {
+                        buffer = existingBuffer;
+                    }
+                }
+                /*
+                 * add to buffer
+                 */
+                if (null != folderPath) {
+                    buffer.add(session, folderID, Arrays.asList(folderPath));
+                } else {
+                    buffer.add(session, folderID);
+                }
+                return null;
             }
-        }
+        };
         /*
-         * add to buffer
+         * add event to buffer asynchronously if possible
          */
-        if (null != folderPath) {
-            buffer.add(session, folderID, Arrays.asList(folderPath));
-        } else {
-            buffer.add(session, folderID);
+        try {
+            ThreadPoolService threadPoolService = DriveEventServiceLookup.getService(ThreadPoolService.class, false);
+            if (null != threadPoolService) {
+                threadPoolService.submit(insertTask, CallerRunsBehavior.<Void>getInstance());
+            } else {
+                insertTask.call();
+            }
+        } catch (Exception e) {
+            LOG.warn("Error adding drive event to folder buffer ", e);
         }
     }
 
     @Override
     public void registerPublisher(DriveEventPublisher publisher) {
-        if (publishers.add(publisher) && LOG.isDebugEnabled()) {
-            LOG.debug("Added drive event publisher: " + publisher);
+        if (publishers.add(publisher)) {
+            LOG.debug("Added drive event publisher: {}", publisher);
         }
     }
 
     @Override
     public void unregisterPublisher(DriveEventPublisher publisher) {
-        if (publishers.remove(publisher) && LOG.isDebugEnabled()) {
-            LOG.debug("Removed drive event publisher: " + publisher);
+        if (publishers.remove(publisher)) {
+            LOG.debug("Removed drive event publisher: {}", publisher);
         }
     }
 
