@@ -51,7 +51,6 @@ package com.openexchange.drive.events.osgi;
 
 import java.util.Dictionary;
 import java.util.Hashtable;
-import org.apache.commons.logging.Log;
 import org.osgi.framework.BundleException;
 import org.osgi.framework.ServiceReference;
 import org.osgi.service.event.EventConstants;
@@ -68,6 +67,7 @@ import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
 import com.openexchange.ms.MsService;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.timer.TimerService;
 
 /**
@@ -77,7 +77,7 @@ import com.openexchange.timer.TimerService;
  */
 public class DriveEventsActivator extends HousekeepingActivator {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(DriveEventsActivator.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DriveEventsActivator.class);
 
     /**
      * Initializes a new {@link DriveEventsActivator}.
@@ -89,7 +89,7 @@ public class DriveEventsActivator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] { IDBasedFileAccessFactory.class, IDBasedFolderAccessFactory.class, TimerService.class,
-            ConfigurationService.class };
+            ConfigurationService.class, ThreadPoolService.class };
     }
 
     @Override
