@@ -57,6 +57,7 @@ import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.capabilities.CapabilityService;
+import com.openexchange.drive.DriveClientVersion;
 import com.openexchange.drive.DriveService;
 import com.openexchange.drive.DriveSession;
 import com.openexchange.drive.events.subscribe.DriveSubscriptionStore;
@@ -111,7 +112,8 @@ public abstract class AbstractDriveAction implements AJAXActionService {
             throw AjaxExceptionCodes.MISSING_PARAMETER.create("root");
         }
         int apiVersion = requestData.containsParameter("apiVersion") ? requestData.getParameter("apiVersion", Integer.class).intValue() : 0;
-        DefaultDriveSession driveSession = new DefaultDriveSession(session, rootFolderID, extractHostData(requestData, session), apiVersion);
+        DefaultDriveSession driveSession = new DefaultDriveSession(
+            session, rootFolderID, extractHostData(requestData, session), apiVersion, extractClientVersion(requestData));
         /*
          * extract device name information if present
          */
@@ -119,6 +121,13 @@ public abstract class AbstractDriveAction implements AJAXActionService {
         if (false == Strings.isEmpty(device)) {
             driveSession.setDeviceName(device);
         }
+        /*
+         * extract push token if present
+         */
+        String pushToken = requestData.getParameter("pushToken");
+        if (false == Strings.isEmpty(pushToken)) {
+            session.setParameter(DriveSession.PARAMETER_PUSH_TOKEN, pushToken);
+        }
         /*
          * extract diagnostics parameter if present
          */
@@ -148,6 +157,18 @@ public abstract class AbstractDriveAction implements AJAXActionService {
         return doPerform(requestData, driveSession);
     }
 
+    private static DriveClientVersion extractClientVersion(AJAXRequestData requestData) throws OXException {
+        String version = requestData.containsParameter("version") ? requestData.getParameter("version") : null;
+        if (Strings.isEmpty(version)) {
+            return DriveClientVersion.VERSION_0;
+        }
+        try {
+            return new DriveClientVersion(version);
+        } catch (IllegalArgumentException e) {
+            throw AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create(e, "version", version);
+        }
+    }
+
     /**
      * Extracts host data from the supplied request and session.
      *
