@@ -60,33 +60,31 @@ import com.openexchange.i18n.LocalizableStrings;
  */
 public final class DriveExceptionMessages implements LocalizableStrings {
 
-    public static final String INVALID_PATH_MSG = "The path \"%1$s\" is invalid";
-    public static final String PATH_NOT_FOUND_MSG = "The path \"%1$s\" was not found";
-    public static final String FILE_NOT_FOUND_MSG = "The file \"%1$s\" was not found at \"%2$s\"";
-    public static final String IO_ERROR_MSG = "An I/O error occurred: \"%1$s\"";
-    public static final String INVALID_FILE_OFFSET_MSG = "The file offset \"%1$d\" is invalid";
-    public static final String DB_ERROR_MSG = "Unexpected database error: \"%1$s\"";
-    public static final String FILEVERSION_NOT_FOUND_MSG = "The file \"%1$s\" with checksum \"%2$s\" was not found at \"%3$s\"";
-    public static final String NO_CHECKSUM_FOR_FILE_MSG = "No checksum for file \"%1$s\" available";
-    public static final String UPLOADED_FILE_CHECKSUM_ERROR_MSG = "Checksum \"%1$s\" for uploaded file \"%2$s\" different from \"%3$s\"";
-    public static final String DIRECTORYVERSION_NOT_FOUND_MSG = "The directory \"%1$s\" with checksum \"%2$s\"";
-    public static final String NO_DELETE_FILE_PERMISSION_MSG = "You are not allowed to delete the file \"%1$s\" at \"%2$s\"";
-    public static final String NO_CREATE_FILE_PERMISSION_MSG = "You are not allowed to create files at \"%1$s\"";
-    public static final String NO_MODIFY_FILE_PERMISSION_MSG = "You are not allowed to modify the file \"%1$s\" at \"%2$s\"";
-    public static final String NO_DELETE_DIRECTORY_PERMISSION_MSG = "You are not allowed to delete the directory \"%1$s\"";
-    public static final String NO_CREATE_DIRECTORY_PERMISSION_MSG = "You are not allowed to create directories at \"%1$s\"";
-    public static final String QUOTA_REACHED_MSG = "The allowed Quota is reached";
-    public static final String INVALID_FILENAME_MSG = "The file name \"%1$s\" is invalid";
-    public static final String IGNORED_FILENAME_MSG = "The file name \"%1$s\" is ignored";
-    public static final String CONFLICTING_PATH_MSG = "The path \"%1$s\" is conflicting";
-    public static final String INVALID_FILEVERSION_MSG = "The file version \"%1$s\" with checksum \"%2$s\" is invalid";
-    public static final String INVALID_DIRECTORYVERSION_MSG = "The directory version \"%1$s\" with checksum \"%2$s\" is invalid";
-    public static final String LONG_POLLING_NOT_AVAILABLE_MSG = "Push via long polling is not available";
+    public static final String PATH_NOT_FOUND_MSG = "The path \"%1$s\" was not found. Please retry the synchronization.";
+    public static final String FILE_NOT_FOUND_MSG = "The file \"%1$s\" was not found at \"%2$s\". Please retry the synchronization.";
+    public static final String INVALID_FILE_OFFSET_MSG = "Unable to access the file at the requested position. Please retry the synchronization.";
+    public static final String FILEVERSION_NOT_FOUND_MSG = "The file version \"%1$s\" was not found at \"%3$s\". Please retry the synchronization.";
+    public static final String UPLOADED_FILE_CHECKSUM_ERROR_MSG = "Integrity checks failed for uploaded file \"%2$s\". Please try again.";
+    public static final String DIRECTORYVERSION_NOT_FOUND_MSG = "The directory version \"%1$s\" was not found. Please retry the synchronization.";
+    public static final String NO_DELETE_FILE_PERMISSION_MSG = "You are not allowed to delete the file \"%1$s\" at \"%2$s\".";
+    public static final String NO_CREATE_FILE_PERMISSION_MSG = "You are not allowed to create files at \"%1$s\".";
+    public static final String NO_MODIFY_FILE_PERMISSION_MSG = "You are not allowed to modify the file \"%1$s\" at \"%2$s\".";
+    public static final String NO_DELETE_DIRECTORY_PERMISSION_MSG = "You are not allowed to delete the directory \"%1$s\".";
+    public static final String NO_CREATE_DIRECTORY_PERMISSION_MSG = "You are not allowed to create directories at \"%1$s\".";
+    public static final String QUOTA_REACHED_MSG = "The allowed quota is reached.";
+    public static final String INVALID_PATH_MSG = "The path \"%1$s\" is invalid.";
+    public static final String INVALID_FILENAME_MSG = "The file name \"%1$s\" is invalid.";
+    public static final String IGNORED_FILENAME_MSG = "The file name \"%1$s\" is ignored.";
+    public static final String CONFLICTING_PATH_MSG = "The path \"%1$s\" is conflicting.";
+    public static final String INVALID_FILEVERSION_MSG = "The file version \"%1$s\" is invalid.";
+    public static final String INVALID_DIRECTORYVERSION_MSG = "The directory version \"%1$s\" is invalid.";
+    public static final String LONG_POLLING_NOT_AVAILABLE_MSG = "Push updates are not available.";
     public static final String SERVER_BUSY_MSG = "The server is too busy at the moment - please try again later.";
-    public static final String IGNORED_PATH_MSG = "The path \"%1$s\" is ignored";
-    public static final String CONFLICTING_FILENAME_MSG = "The file name \"%1$s\" is conflicting";
-    public static final String REPEATED_SYNC_PROBLEMS_MSG = "The directory \"%1$s\" with checksum \"%2$s\" caused repeated synchronization problems";
-    public static final String CLIENT_OUTDATED_MSG = "The client application you're using is outdated and no longer supported - please upgrade to a newer version";
+    public static final String IGNORED_PATH_MSG = "The path \"%1$s\" is ignored.";
+    public static final String CONFLICTING_FILENAME_MSG = "The file name \"%1$s\" is conflicting.";
+    public static final String REPEATED_SYNC_PROBLEMS_MSG = "The directory \"%1$s\" caused repeated synchronization problems.";
+    public static final String CLIENT_OUTDATED_MSG = "The client application you're using is outdated and no longer supported - please upgrade to a newer version.";
+    public static final String CLIENT_VERSION_UPDATE_AVAILABLE_MSG = "A newer version of your client application is available for download.";
 
     /**
      * Prevent instantiation.
