@@ -56,11 +56,11 @@ import java.util.Collections;
 import java.util.Date;
 import java.util.List;
 import com.openexchange.ajax.container.IFileHolder;
-import com.openexchange.config.ConfigurationService;
 import com.openexchange.drive.Action;
 import com.openexchange.drive.DirectoryMetadata;
 import com.openexchange.drive.DirectoryVersion;
 import com.openexchange.drive.DriveAction;
+import com.openexchange.drive.DriveClientVersion;
 import com.openexchange.drive.DriveConstants;
 import com.openexchange.drive.DriveExceptionCodes;
 import com.openexchange.drive.DriveFileField;
@@ -68,6 +68,7 @@ import com.openexchange.drive.DriveFileMetadata;
 import com.openexchange.drive.DriveQuota;
 import com.openexchange.drive.DriveService;
 import com.openexchange.drive.DriveSession;
+import com.openexchange.drive.DriveSettings;
 import com.openexchange.drive.FileVersion;
 import com.openexchange.drive.SyncResult;
 import com.openexchange.drive.actions.AbstractAction;
@@ -86,6 +87,7 @@ import com.openexchange.drive.comparison.FileVersionMapper;
 import com.openexchange.drive.comparison.ServerDirectoryVersion;
 import com.openexchange.drive.comparison.ServerFileVersion;
 import com.openexchange.drive.internal.tracking.SyncTracker;
+import com.openexchange.drive.management.DriveConfig;
 import com.openexchange.drive.storage.execute.DirectoryActionExecutor;
 import com.openexchange.drive.storage.execute.FileActionExecutor;
 import com.openexchange.drive.sync.DefaultSyncResult;
@@ -109,7 +111,7 @@ import com.openexchange.java.StringAllocator;
  */
 public class DriveServiceImpl implements DriveService {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.loggerFor(DriveServiceImpl.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DriveServiceImpl.class);
 
     /**
      * Initializes a new {@link DriveServiceImpl}.
@@ -123,15 +125,29 @@ public class DriveServiceImpl implements DriveService {
     public SyncResult<DirectoryVersion> syncFolders(DriveSession session, List<DirectoryVersion> originalVersions,
         List<DirectoryVersion> clientVersions) throws OXException {
         /*
-         * check api version first
+         * check (hard) version restrictions
          */
-        if (session.getApiVersion() < DriveServiceLookup.getService(ConfigurationService.class)
-            .getIntProperty("com.openexchange.drive.minApiVersion", DriveConstants.DEFAULT_MIN_API_VERSION)) {
+        if (session.getApiVersion() < DriveConfig.getInstance().getMinApiVersion()) {
             OXException error = DriveExceptionCodes.CLIENT_OUTDATED.create();
+            LOG.warn("Client synchronization aborted for " + session, error);
             List<AbstractAction<DirectoryVersion>> actionsForClient = new ArrayList<AbstractAction<DirectoryVersion>>(1);
             actionsForClient.add(new ErrorDirectoryAction(null, null, null, error, false, true));
             return new DefaultSyncResult<DirectoryVersion>(actionsForClient, error.getLogMessage());
         }
+        DriveClientVersion clientVersion = session.getClientVersion();
+        if (null != clientVersion) {
+            DriveClientVersion hardVersionLimit = DriveConfig.getInstance().getHardMinimumVersion(session.getClientType());
+            if (0 > clientVersion.compareTo(hardVersionLimit)) {
+                OXException error = DriveExceptionCodes.CLIENT_VERSION_OUTDATED.create(clientVersion, hardVersionLimit);
+                LOG.warn("Client synchronization aborted for " + session, error);
+                List<AbstractAction<DirectoryVersion>> actionsForClient = new ArrayList<AbstractAction<DirectoryVersion>>(1);
+                actionsForClient.add(new ErrorDirectoryAction(null, null, null, error, false, true));
+                return new DefaultSyncResult<DirectoryVersion>(actionsForClient, error.getLogMessage());
+            }
+        }
+        /*
+         * sync folders
+         */
         long start = System.currentTimeMillis();
         DriveVersionValidator.validateDirectoryVersions(originalVersions);
         DriveVersionValidator.validateDirectoryVersions(clientVersions);
@@ -156,7 +172,7 @@ public class DriveServiceImpl implements DriveService {
                 DirectoryActionExecutor executor = new DirectoryActionExecutor(driveSession, true, retryCount < DriveConstants.MAX_RETRIES);
                 executor.execute(syncResult.getActionsForServer());
             } catch (OXException e) {
-                if (tryAgain(e) && retryCount <= DriveConstants.MAX_RETRIES) {
+                if (0 == retryCount || (tryAgain(e) && retryCount <= DriveConstants.MAX_RETRIES)) {
                     retryCount++;
                     int delay = DriveConstants.RETRY_BASEDELAY * retryCount;
                     driveSession.trace("Got exception during execution of server actions (" + e.getMessage() + "), trying again in " +
@@ -165,7 +181,7 @@ public class DriveServiceImpl implements DriveService {
                     continue;
                 }
                 driveSession.trace("Got exception during execution of server actions (" + e.getMessage() + ")");
-                LOG.debug("Got exception during execution of server actions (" + e.getMessage() + ")", e);
+                LOG.warn("Got exception during execution of server actions\nPrevious sync result:\n{}", syncResult, e);
                 throw e;
             }
             /*
@@ -174,6 +190,17 @@ public class DriveServiceImpl implements DriveService {
             if (syncResult.isEmpty()) {
                 TempCleaner.cleanUpIfNeeded(driveSession);
             }
+            /*
+             * check (soft) version restrictions
+             */
+            if (null != clientVersion) {
+                DriveClientVersion softVersionLimit = DriveConfig.getInstance().getSoftMinimumVersion(session.getClientType());
+                if (0 > clientVersion.compareTo(softVersionLimit)) {
+                    OXException error = DriveExceptionCodes.CLIENT_VERSION_UPDATE_AVAILABLE.create(clientVersion, softVersionLimit);
+                    LOG.trace("Client upgrade available for " + session, error);
+                    syncResult.addActionForClient(new ErrorDirectoryAction(null, null, null, error, false, false));
+                }
+            }
             /*
              * return actions for client
              */
@@ -211,7 +238,7 @@ public class DriveServiceImpl implements DriveService {
                 FileActionExecutor executor = new FileActionExecutor(driveSession, true, retryCount < DriveConstants.MAX_RETRIES, path);
                 executor.execute(syncResult.getActionsForServer());
             } catch (OXException e) {
-                if (tryAgain(e) && retryCount <= DriveConstants.MAX_RETRIES) {
+                if (0 == retryCount || (tryAgain(e) && retryCount <= DriveConstants.MAX_RETRIES)) {
                     retryCount++;
                     int delay = DriveConstants.RETRY_BASEDELAY * retryCount;
                     driveSession.trace("Got exception during execution of server actions (" + e.getMessage() + "), trying again in " +
@@ -235,10 +262,7 @@ public class DriveServiceImpl implements DriveService {
     public IFileHolder download(DriveSession session, String path, FileVersion fileVersion, long offset, long length) throws OXException {
         DriveVersionValidator.validateFileVersion(fileVersion);
         SyncSession driveSession = new SyncSession(session);
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Handling download: file version: " + fileVersion + ", offset: " + offset + ", length: " + length);
-        }
-        IFileHolder fileHolder = new DownloadHelper(driveSession).perform(path, fileVersion, offset, length);
+        LOG.debug("Handling download: file version: {}, offset: {}, length: {}", fileVersion, offset, length);
         /*
          * track sync result to represent the download as performed by client
          */
@@ -251,13 +275,12 @@ public class DriveServiceImpl implements DriveService {
         };
         action.getParameters().put(DriveAction.PARAMETER_OFFSET, Long.valueOf(offset));
         action.getParameters().put(DriveAction.PARAMETER_LENGTH, Long.valueOf(length));
-        List<AbstractAction<FileVersion>> actionsForServer = Collections.emptyList();
-        List<AbstractAction<FileVersion>> actionsForClient = Collections.singletonList(action);
-        new SyncTracker(driveSession).track(new IntermediateSyncResult<FileVersion>(actionsForServer, actionsForClient), path);
+        new SyncTracker(driveSession).track(new IntermediateSyncResult<FileVersion>(
+            Collections.<AbstractAction<FileVersion>>emptyList(), Collections.<AbstractAction<FileVersion>>singletonList(action)), path);
         /*
          * return file holder for download
          */
-        return fileHolder;
+        return new DownloadHelper(driveSession).perform(path, fileVersion, offset, length);
     }
 
     @Override
@@ -279,6 +302,7 @@ public class DriveServiceImpl implements DriveService {
         try {
             createdFile = new UploadHelper(driveSession).perform(path, originalVersion, newVersion, uploadStream, contentType, offset, totalLength, created, modified);
         } catch (OXException e) {
+            LOG.warn("Got exception during upload ({})\nSession: {}, path: {}, original version: {}, new version: {}, offset: {}, total length: {}",e.getMessage(),driveSession,path,originalVersion,newVersion,offset,totalLength);
             if ("FLS-0024".equals(e.getErrorCode())) {
                 /*
                  * quota reached
@@ -290,7 +314,7 @@ public class DriveServiceImpl implements DriveService {
                      */
                     String alternativeName = RenameTools.findRandomAlternativeName(originalVersion.getName());
                     FileVersion renamedVersion = new SimpleFileVersion(alternativeName, originalVersion.getChecksum());
-                    syncResult.addActionForClient(new EditFileAction(newVersion, renamedVersion, null, path));
+                    syncResult.addActionForClient(new EditFileAction(newVersion, renamedVersion, null, path, false));
                     syncResult.addActionForClient(new ErrorFileAction(newVersion, renamedVersion, null, path, quotaException, true));
                     /*
                      * ... then download the server version afterwards
@@ -341,27 +365,20 @@ public class DriveServiceImpl implements DriveService {
 
     @Override
     public DriveQuota getQuota(DriveSession session) throws OXException {
-        final SyncSession driveSession = new SyncSession(session);
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Handling get-quota for root folder '" + session.getRootFolderID() + "'");
-        }
-        final Quota[] quota = driveSession.getStorage().getQuota();
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Got quota for root folder '" + session.getRootFolderID() + "': " + quota);
-        }
-        final String manageLink = new DirectLinkGenerator(driveSession).getQuotaLink();
-        return new DriveQuota() {
+        return getSettings(session).getQuota();
+    }
 
-            @Override
-            public Quota[] getQuota() {
-                return quota;
-            }
-
-            @Override
-            public String getManageLink() {
-                return manageLink;
-            }
-        };
+    @Override
+    public DriveSettings getSettings(DriveSession session) throws OXException {
+        SyncSession syncSession = new SyncSession(session);
+        LOG.debug("Handling get-settings for '{}'", session);
+        DriveSettings settings = new DriveSettings();
+        Quota[] quota = syncSession.getStorage().getQuota();
+        LOG.debug("Got quota for root folder '{}': {}", session.getRootFolderID(), quota);
+        settings.setQuota(new DriveQuotaImpl(quota, syncSession.getLinkGenerator().getQuotaLink()));
+        settings.setHelpLink(syncSession.getLinkGenerator().getHelpLink());
+        settings.setServerVersion(com.openexchange.version.Version.getInstance().getVersionString());
+        return settings;
     }
 
     @Override
