@@ -52,10 +52,10 @@ package com.openexchange.drive.internal;
 import static com.openexchange.drive.DriveConstants.TEMP_PATH;
 import java.security.NoSuchAlgorithmException;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import jonelo.jacksum.algorithm.MD;
-import com.openexchange.config.ConfigurationService;
 import com.openexchange.drive.DriveConstants;
 import com.openexchange.drive.DriveExceptionCodes;
 import com.openexchange.drive.DriveFileField;
@@ -67,6 +67,7 @@ import com.openexchange.drive.checksum.FileChecksum;
 import com.openexchange.drive.checksum.rdb.RdbChecksumStore;
 import com.openexchange.drive.comparison.ServerDirectoryVersion;
 import com.openexchange.drive.comparison.ServerFileVersion;
+import com.openexchange.drive.management.DriveConfig;
 import com.openexchange.drive.storage.DriveStorage;
 import com.openexchange.drive.storage.StorageOperation;
 import com.openexchange.exception.OXException;
@@ -103,7 +104,8 @@ public class SyncSession {
         if (isTraceEnabled()) {
             trace("Creating new sync session for user " + session.getServerSession().getLoginName() + " (" +
                 session.getServerSession().getUserId() + ") in context " + session.getServerSession().getContextId() +
-                ", root folder ID is " + session.getRootFolderID());
+                ", root folder ID is " + session.getRootFolderID() +
+                " via client " + session.getClientType() + " v" + session.getClientVersion());
         }
     }
 
@@ -231,9 +233,7 @@ public class SyncSession {
             /*
              * check configuration first
              */
-            ConfigurationService configService = DriveServiceLookup.getService(ConfigurationService.class);
-            if (null != configService && false ==
-                Boolean.valueOf(configService.getBoolProperty("com.openexchange.drive.useTempFolder", false))) {
+            if (false == DriveConfig.getInstance().isUseTempFolder()) {
                 trace("Temporary folder for upload is disabled by configuration.");
                 hasTempFolder = Boolean.FALSE;
             } else {
@@ -242,17 +242,26 @@ public class SyncSession {
                  */
                 FileStorageFolder tempFolder = getStorage().optFolder(TEMP_PATH, false);
                 if (null == tempFolder) {
-                    try {
-                        tempFolder = getStorage().optFolder(TEMP_PATH, true);
-                    } catch (OXException e) {
-                        trace("Error creating temporary folder for uploads: " + e.getMessage());
+                    FileStorageFolder rootFolder = getStorage().getFolder(DriveConstants.ROOT_PATH);
+                    if (null != rootFolder.getOwnPermission() &&
+                        FileStoragePermission.CREATE_SUB_FOLDERS <= rootFolder.getOwnPermission().getDeletePermission() &&
+                        FileStoragePermission.WRITE_ALL_OBJECTS <= rootFolder.getOwnPermission().getFolderPermission() &&
+                        FileStoragePermission.READ_ALL_OBJECTS <= rootFolder.getOwnPermission().getFolderPermission() &&
+                        FileStoragePermission.DELETE_ALL_OBJECTS <= rootFolder.getOwnPermission().getDeletePermission()) {
+                        try {
+                            tempFolder = getStorage().optFolder(TEMP_PATH, true);
+                        } catch (OXException e) {
+                            trace("Error creating temporary folder for uploads: " + e.getMessage());
+                        }
                     }
                 }
                 if (null == tempFolder) {
                     trace("No temporary folder available for uploads.");
                     hasTempFolder = Boolean.FALSE;
                 } else if (null != tempFolder.getOwnPermission() &&
-                    FileStoragePermission.CREATE_OBJECTS_IN_FOLDER <= tempFolder.getOwnPermission().getFolderPermission()) {
+                    FileStoragePermission.CREATE_OBJECTS_IN_FOLDER <= tempFolder.getOwnPermission().getFolderPermission() &&
+                    FileStoragePermission.WRITE_ALL_OBJECTS <= tempFolder.getOwnPermission().getFolderPermission() &&
+                    FileStoragePermission.DELETE_ALL_OBJECTS <= tempFolder.getOwnPermission().getDeletePermission()) {
                     trace("Using folder '" + tempFolder + "' for temporary uploads.");
                     hasTempFolder = Boolean.TRUE;
                 } else {
@@ -265,9 +274,13 @@ public class SyncSession {
     }
 
     public List<ServerFileVersion> getServerFiles(String path) throws OXException {
-        String folderID = getStorage().getFolderID(path);
-        List<File> files = getStorage().getFilesInFolder(folderID);
-        List<FileChecksum> checksums = ChecksumProvider.getChecksums(this, folderID, files);
+        FileStorageFolder folder = getStorage().getFolder(path);
+        if (null == folder || null == folder.getOwnPermission() ||
+            FileStoragePermission.READ_OWN_OBJECTS > folder.getOwnPermission().getReadPermission()) {
+            return Collections.emptyList();
+        }
+        List<File> files = getStorage().getFilesInFolder(folder.getId());
+        List<FileChecksum> checksums = ChecksumProvider.getChecksums(this, folder.getId(), files);
         List<ServerFileVersion> serverFiles = new ArrayList<ServerFileVersion>(files.size());
         for (int i = 0; i < files.size(); i++) {
             serverFiles.add(new ServerFileVersion(files.get(i), checksums.get(i)));
