@@ -50,7 +50,6 @@
 package com.openexchange.drive.sync;
 
 import java.util.Map.Entry;
-import org.apache.commons.logging.Log;
 import com.openexchange.drive.DriveVersion;
 import com.openexchange.drive.comparison.Change;
 import com.openexchange.drive.comparison.ThreeWayComparison;
@@ -66,7 +65,7 @@ import com.openexchange.exception.OXException;
  */
 public abstract class Synchronizer<T extends DriveVersion> {
 
-    protected static final Log LOG = com.openexchange.log.Log.loggerFor(Synchronizer.class);
+    protected static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(Synchronizer.class);
 
     protected final SyncSession session;
     protected final VersionMapper<T> mapper;
